@@ -5,7 +5,7 @@ from functools import partial
 import click
 import pandas as pd
 
-from finam.export import Exporter, Market, FinamObjectNotFoundError
+from finam import Exporter, Market, FinamObjectNotFoundError
 from finam.utils import click_validate_enum
 
 
@@ -45,5 +45,5 @@ def main(contract, market):
 
 
 if __name__ == '__main__':
-    logging.basicConfig(level=logging.DEBUG)
+    logging.basicConfig(level=logging.INFO)
     main()
